<?php
/**
 * Created by PhpStorm.
 * User: ronald
 * Date: 11/6/15
 * Time: 09:11
 * @file
 * Contains \Drupal\simplyhired\Form\SimplyHiredSettingsForm
 */

namespace Drupal\simplyhired\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Url;
use Drupal\Core\Link;
use Drupal\simplyhired\SimplyHiredService;


class SimplyHiredSettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'simplyhired_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'simplyhired.settings'
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('simplyhired.settings');

    $portal_msg = $this->t('You can obtain your Publisher ID and API key by logging in to the @portal_link then clicking on the XML API tab.',
      array(
        '@portal_link' => Link::fromTextAndUrl(t('Simply Hired Partner portal'), Url::fromUri('https://simply-partner.com/partner/', array('external' => TRUE, 'attributes' => array('target' => '_blank') ) ) ),
      )
    );

    $form['pshid'] = array(
      '#type' => 'textfield',
      '#title' => $this->t('Publisher ID'),
      '#default_value' => $config->get('pshid'),
    );

    $form['auth'] = array(
      '#type' => 'textfield',
      '#title' => $this->t('API key'),
      '#default_value' => $config->get('auth'),
      '#description' => $portal_msg,
    );

    $form['default_source'] = array(
      '#type' => 'select',
      '#title' => $this->t('API source'),
      '#default_value' => $config->get('default_source'),
      '#options' => SimplyHiredService::getEndpointOptions(),
      '#description' => $this->t('When not specified, this API endpoint will be used.'),
    );
    // TODO: fix this according to D8 methods.


    $attr_markup = $this->t('Use of the Simply Hired API is governed by the @tos_link, which, among other things, requires that publishers show the Simply Hired attribution on every page that incorporates data returned from the API.',
        array(
          '@tos_link' => Link::fromTextAndUrl($this->t('Terms of Service'), Url::fromUri('https://simply-partner.com/partner-terms/1', array('external' => TRUE, 'attributes' => array('target' => '_blank') ) ) ),
        )
      );

    $attr_markup .= ' ' . $this->t('The module developer is not responsible if you disable the attribution markup.');

    $form['display_attribution'] = array(
      '#type' => 'checkbox',
      '#title' => $this->t('Display attribution image'),
      '#default_value' => $config->get('display_attribution'),
      '#description' => '<div class="messages messages--warning attribution-message">' . $attr_markup . '</div>',
    );

    $form['attribution_type'] = array(
      '#type' => 'radios',
      '#title' => $this->t('Attribution image'),
      '#default_value' => $config->get('attribution_type'),
      '#options' => array('default' => $this->t('Default'), 'light' => $this->t('Light'))
    );

    $module_path = drupal_get_path('module', 'simplyhired');

    $attr_images = array(
      array('#markup' => '<img src="/' . $module_path . '/images/sh-jobsby-default.png" /><br /><em>' . $this->t('Default') . '</em>'),
      array('#markup' => '<img src="/' . $module_path . '/images/sh-jobsby-light.png" /><br /><em>' . $this->t('Light') . '</em>'),
    );
    /*
    $attr_images = array(
      array(
        '#theme' => 'image',
        '#path' => $module_path . '/images/sh-jobsby-default.png',
        '#alt' => $this->t('Default Simply Hired attribution image.'),
        '#title' => $this->t('Default Simply Hired attribution image.')
      ),
      array(
        '#theme' => 'image',
        '#path' => $module_path . '/images/sh-jobsby-default.png',
        '#alt' => $this->t('Light background Simply Hired attribution image.'),
        '#title' => $this->t('Light background Simply Hired attribution image.')
      )
    );
    */
    $form['attribution_image_sample'] = array(
      '#theme' => 'item_list',
      '#items' => $attr_images,
      '#title' => $this->t('Attribution image options'),
      '#list_type' => 'ul',
      '#prefix' => '<div class="attribution-image-sample">',
      '#suffix' => '</div>'
    );

    // Add our css.
    $form['#attached']['library'][] = 'simplyhired/simplyhired-settings';


    return parent::buildForm($form, $form_state);
  }

  public function submitForm(array &$form, FormStateInterface $form_state) {
    $config = $this->config('simplyhired.settings');

    $values = $form_state->getValues();

    $config->set('pshid', $values['pshid'])
      ->set('auth', $values['auth'])
      ->set('default_source', $values['default_source'])
      ->set('display_attribution', (bool) $values['display_attribution'])
      ->set('attribution_type', $values['attribution_type'])
      ->save();

    parent::submitForm($form, $form_state);
  }
  
}